<?php
/**
 * Enqueues front-end CSS for color scheme.
 *
 * @since Twenty Fifteen 1.0
 *
 * @see wp_add_inline_style()
 */
function finance_color_scheme_css() {
	global $finance_option; 
	wp_add_inline_style( 'finance-style', finance_get_color_scheme_css() );
}
add_action( 'wp_enqueue_scripts', 'finance_color_scheme_css' );

/**
 * Returns CSS for the color schemes.
 *
 * @since Twenty Fifteen 1.0
 *
 * @param array $colors Color scheme colors.
 * @return string Color scheme CSS.
 */
function finance_get_color_scheme_css() {
	global $finance_option;

	$css = <<<CSS

	::selection {
	  color: #fff;
	  background: {$finance_option['main-color']};
	}
	::-moz-selection {
	  color: #fff;
	  background: {$finance_option['main-color']};
	}
	/* default color: #00abc9 */
	.item-lastest-news .news-text-container .tags a, .widget-area ul li:hover a, .item-lastest-news h3:hover, .widget .search-form .search-submit:hover,
	.footer-link ul li a:hover,.footer-col-1 ul li:hover a,.breadcrumb-finance a:hover,ul.style-list-circle li:hover a,ul.style-list-circle li:before,
	.tags-bottom a, .share-bottom a,.preview_entry_post:hover span, .next_entry_post:hover span, .preview_entry_post:hover h3, .next_entry_post:hover h3,
	.comment-respond .logged-in-as a:hover,.comments-area ol.comment-list li.comment .comment-content cite a,
	.comments-area ol.comment-list li.comment .comment-content .reply a,ul.social-dark li a,.customNavigation .btn:hover,
	ul.countdown li span,.project-terms .current,.projectContainer3column .element-item h5:hover,.item-services .caption .learn-more,
	.services-list-2 .thumbnail-icon-item .learn-more,.item-blog .caption .learn-more,.more-all,.btn-border:hover, .btn-border:focus,
	.mm-toggle:hover,.services-list-2 .thumbnail-icon-item .learn-more i,.promotion .promotionText a,.widget-area ul li:hover:before,
	.site-main .tags a, .item-lastest-news h3 a:hover, .header .navi-desktop-site ul li.current-menu-ancestor > a
	{color:{$finance_option['main-color']};}

	.tagcloud a:hover, .header .navi-desktop-site .navi-level-1 li .navi-level-2,.pagination-finance > li > .current,#to-the-top:hover,
	.btn-main-color,div.acc2.vc_tta-color-white.vc_tta-style-classic .vc_tta-panel.vc_active .vc_tta-panel-title>a,
	div.acc2.vc_tta-color-white.vc_tta-style-classic .vc_tta-panel .vc_tta-panel-title>a:hover,.widget_nav_menu ul li.current-menu-item a,
	.bar-chart,.owl-project .item h5,.call-back-form div.fancy-select ul.options li.selected, .call-back-form div.fancy-select ul.options li:hover,
	.call-back-form div.fancy-select ul.options li:hover,.item-services .services-3-column-img-container:hover h4,
	div.acc1.vc_tta-color-black.vc_tta-style-classic .vc_tta-panel.vc_active .vc_tta-panel-title>a,
	div.acc1.vc_tta.vc_tta-accordion .vc_tta-controls-icon-position-left.vc_tta-panel-title>a:hover,
	.tab2.vc_tta-tabs:not([class*=vc_tta-gap]):not(.vc_tta-o-no-fill).vc_tta-tabs-position-top .vc_tta-tab.vc_active>a,
	.tab3.vc_tta-tabs:not([class*=vc_tta-gap]):not(.vc_tta-o-no-fill).vc_tta-tabs-position-top .vc_tta-tab.vc_active>a,
	div.tab4.vc_tta-tabs:not([class*=vc_tta-gap]):not(.vc_tta-o-no-fill).vc_tta-tabs-position-top .vc_tta-tab.vc_active>a::after,
	.footer-col-1 ul li:hover:before,.pagination-finance > li > .current:hover,
	.header-v3 nav .search-container .form-search-navi .btn-search-navi.active, .header-v4 nav .search-container .form-search-navi .btn-search-navi.active,
	ul.social li:hover a
	{background-color:{$finance_option['main-color']};}

	.promotion .promotionText .btn-buy-now:hover {
		background-color:{$finance_option['main-color']};
		border: 1px solid #fff;
		color: #fff;
	}

	.mobile-menu .open, .mobile-menu .open + a {
	  color: {$finance_option['main-color']} !important;
	}

	.customNavigation .btn:hover,.widget_nav_menu ul li.current-menu-item a,.avatar-testimonials-1-columns .owl-wrapper .synced .item img,
	.btn-border:hover, .btn-border:focus,.promotion .promotionText .btn-buy-now,.tagcloud a:hover,.pagination-finance > li > .current,
	.pagination-finance > li > .current:hover
	{border-color:{$finance_option['main-color']};}

	.vc_tta-tabs:not([class*=vc_tta-gap]):not(.vc_tta-o-no-fill).vc_tta-tabs-position-top .vc_tta-tab.vc_active>a
	{border-top-color:{$finance_option['main-color']};}

	.tab2.vc_tta.vc_tta-spacing-1 .vc_tta-tabs-list,ul.countdown li
	{border-bottom-color:{$finance_option['main-color']};}

	/* default color hover: #008096 */
	.header .navi-desktop-site .navi-level-2 li:hover,
	.call-back-form .btn-submit:hover, .header .navi-desktop-site ul ul li.current-menu-item > a
	{background-color:{$finance_option['main-color-hover']};}

	.comments-area ol.comment-list li.comment .comment-content cite a:hover,.comments-area ol.comment-list li.comment .comment-content .reply a:hover,
	.tags-bottom a:hover, .share-bottom a:hover,.projectContainer3column .element-item .cateProject:hover,.item-services .learn-more:hover,.services-list-2 .thumbnail-icon-item .learn-more:hover,
	.more-all:hover,.item-lastest-news .news-text-container .tags a:hover,.services-list-2 .thumbnail-icon-item .learn-more:hover i,
	.site-main .tags a:hover,.item-blog .learn-more:hover, .item-blog .caption a h4:hover
	{color:{$finance_option['main-color-hover']};}

	{$finance_option['custom-css']}
CSS;

	return $css;
}