<?php

/**
 * Register meta boxes
 *
 * @since 1.0
 *
 * @param array $meta_boxes
 *
 * @return array
 */

function finance_register_meta_boxes( $meta_boxes ) {

	$prefix = '_cmb_';
	$meta_boxes[] = array(
		'id'       => 'format_detail',
		'title'    => esc_html__( 'Format Details', 'finance' ),
		'pages'    => array( 'post' ),
		'context'  => 'normal',
		'priority' => 'high',
		'autosave' => true,
		'fields'   => array(
			array(
				'name'             => esc_html__( 'Image', 'finance' ),
				'id'               => $prefix . 'image',
				'type'             => 'image_advanced',
				'class'            => 'image',
				'max_file_uploads' => 1,
			),
			array(
				'name'  => esc_html__( 'Gallery', 'finance' ),
				'id'    => $prefix . 'images',
				'type'  => 'image_advanced',
				'class' => 'gallery',
			),
			array(
				'name'  => esc_html__( 'Quote', 'finance' ),
				'id'    => $prefix . 'quote',
				'type'  => 'textarea',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'quote',
			),
			array(
				'name'  => esc_html__( 'Author', 'finance' ),
				'id'    => $prefix . 'quote_author',
				'type'  => 'text',
				'class' => 'quote',
			),
			array(
				'name'  => esc_html__( 'Audio', 'finance' ),
				'id'    => $prefix . 'link_audio',
				'type'  => 'oembed',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'audio',
				'desc' => 'Ex: https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/139083759',
			),
			array(
				'name'  => esc_html__( 'Video', 'finance' ),
				'id'    => $prefix . 'link_video',
				'type'  => 'oembed',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'video',
				'desc' => 'Example: <b>http://www.youtube.com/embed/0ecv0bT9DEo</b> or <b>http://player.vimeo.com/video/47355798</b>',
			),			
		),
	);
	
	$meta_boxes[] = array(
		'id'         => 'info_services',
		'title'      => 'Services Details',
		'pages'      => array( 'service' ), // Post type
		'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
		//'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
		'fields' => array(
			array(
                'name' => 'Subtitle',
                'desc' => 'Subtitle',
                'id'   => $prefix . 'subtitle_service',
				'type'  => 'textarea',
				'cols'  => 20,
				'rows'  => 2,
				'class' => '',
            ),
			array(
				'name'  => esc_html__( 'Link', 'finance' ),
				'id'    => $prefix . 'link_service',
				'type'  => 'text',
				'class' => '',
			),
		)
	);
		
	$meta_boxes[] = array(
		'id'         => 'job_testimonial',
		'title'      => esc_html__('Testimonials Details', 'finance'),
		'pages'      => array( 'testimonial' ), // Post type
		'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
		//'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
		'fields' => array(
			array(
                'name' => esc_html__('Job', 'finance'),
                'desc' => esc_html__('Job of Person', 'finance'),
                'id'   => $prefix . 'job_testi',
                'type' => 'text',
            ),
		)
	);

	$meta_boxes[] = array(
		'id'       => 'team_detail',
		'title'    => esc_html__( 'Team Info', 'finance' ),
		'pages'    => array( 'team' ),
		'context'  => 'normal',
		'priority' => 'high',
		'autosave' => true,
		'fields'   => array(
			array(
				'name'  => esc_html__( 'Job', 'finance' ),
				'id'    => $prefix . 'team_job',
				'type'  => 'text',
				'class' => '',
			),
			array(
				'name'  => esc_html__( 'Excerpt', 'finance' ),
				'id'    => $prefix . 'team_ex',
				'type'  => 'textarea',
				'cols'  => 20,
				'rows'  => 2,
				'class' => '',
			),
			array(
				'name'  => esc_html__( 'Facebook', 'finance' ),
				'id'    => $prefix . 'team_fb',
				'type'  => 'text',
				'class' => '',
			),
			array(
				'name'  => esc_html__( 'Twitter', 'finance' ),
				'id'    => $prefix . 'team_tw',
				'type'  => 'text',
				'class' => '',
			),
			array(
				'name'  => esc_html__( 'Google Plus', 'finance' ),
				'id'    => $prefix . 'team_gp',
				'type'  => 'text',
				'class' => '',
			),
			array(
				'name'  => esc_html__( 'Linkedin', 'finance' ),
				'id'    => $prefix . 'team_li',
				'type'  => 'text',
				'class' => '',
			),
			array(
				'name'  => esc_html__( 'Dribbble', 'finance' ),
				'id'    => $prefix . 'team_dr',
				'type'  => 'text',
				'class' => '',
			),
			array(
				'name'  => esc_html__( 'Pinterest', 'finance' ),
				'id'    => $prefix . 'team_pt',
				'type'  => 'text',
				'class' => '',
			),
			array(
				'name'  => esc_html__( 'Instagram', 'finance' ),
				'id'    => $prefix . 'team_in',
				'type'  => 'text',
				'class' => '',
			),
			array(
				'name'  => esc_html__( 'Youtube', 'finance' ),
				'id'    => $prefix . 'team_yt',
				'type'  => 'text',
				'class' => '',
			),
			array(
				'name'  => esc_html__( 'Email', 'finance' ),
				'id'    => $prefix . 'team_email',
				'type'  => 'text',
				'class' => '',
			),		
			array(
				'name'  => esc_html__( 'Skype', 'finance' ),
				'id'    => $prefix . 'team_skype',
				'type'  => 'text',
				'class' => '',
			),			
		),
	);	

	return $meta_boxes;
}
add_filter( 'rwmb_meta_boxes', 'finance_register_meta_boxes' );

