<?php

    /**
     * For full documentation, please visit: http://docs.reduxframework.com/
     * For a more extensive sample-config file, you may look at:
     * https://github.com/reduxframework/redux-framework/blob/master/sample/sample-config.php
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = "finance_option";

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        'opt_name' => 'finance_option',
        'use_cdn' => TRUE,
        'display_name'     => $theme->get('Name'),
        'display_version'  => $theme->get('Version'),
        'page_title' => 'Finance Options',
        'update_notice' => FALSE,
        'admin_bar' => TRUE,
        'menu_type' => 'menu',
        'menu_title' => 'Finance Options',
        'allow_sub_menu' => TRUE,
        'page_parent_post_type' => 'your_post_type',
        'customizer' => FALSE,
        'dev_mode'   => false,
        'default_mark' => '*',
        'hints' => array(
            'icon_position' => 'right',
            'icon_color' => 'lightgray',
            'icon_size' => 'normal',
            'tip_style' => array(
                'color' => 'light',
            ),
            'tip_position' => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect' => array(
                'show' => array(
                    'duration' => '500',
                    'event' => 'mouseover',
                ),
                'hide' => array(
                    'duration' => '500',
                    'event' => 'mouseleave unfocus',
                ),
            ),
        ),
        'output' => TRUE,
        'output_tag' => TRUE,
        'settings_api' => TRUE,
        'cdn_check_time' => '1440',
        'compiler' => TRUE,
        'page_permissions' => 'manage_options',
        'save_defaults' => TRUE,
        'show_import_export' => TRUE,
        'database' => 'options',
        'transient_time' => '3600',
        'network_sites' => TRUE,
    );    

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */

    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => esc_html__( 'Theme Information 1', 'finance' ),
            'content' => esc_html__( 'This is the tab content, HTML is allowed.', 'finance' )
        ),
        array(
            'id'      => 'redux-help-tab-2',
            'title'   => esc_html__( 'Theme Information 2', 'finance' ),
            'content' => esc_html__( 'This is the tab content, HTML is allowed.', 'finance' ) 
        )
    );
    Redux::setHelpTab( $opt_name, $tabs );

    // Set the help sidebar
    $content = esc_html__( '<p>This is the sidebar content, HTML is allowed.</p>', 'finance' );
    Redux::setHelpSidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    // ACTUAL DECLARATION OF SECTIONS          
    Redux::setSection( $opt_name, array(
        'icon' => ' el-icon-stackoverflow',
        'title' => esc_html__('Miscellaneous Settings', 'finance'),
        'fields' => array(
            array(
                'id'       => 'preload-switch',
                'type'     => 'switch', 
                'title'    => esc_html__('Preload Off?', 'finance'),
                'subtitle' => esc_html__('Look, it\'s on!', 'finance'),
                'default'  => true,
            ),    
            array(
                'id'       => 'bread-switch',
                'type'     => 'switch', 
                'title'    => esc_html__('Breadcrumbs Off?', 'finance'),
                'subtitle' => esc_html__('Look, it\'s on!', 'finance'),
                'default'  => true,
            ),    
            array(
                'id' => 'gmap_api',
                'type' => 'text',
                'title' => esc_html__('Google Map API Key', 'finance'),
                'subtitle' => esc_html__('Add your Google map api key', 'finance'),
                'desc' => esc_html__('Create your Gmap API key here: https://developers.google.com/maps/documentation/javascript/get-api-key', 'finance'),
                'default' => ''
            ),                                                      
        )
    ) );

    Redux::setSection( $opt_name, array(
        'icon' => ' el-icon-picture',
        'title' => esc_html__('Logo & Favicon Settings', 'finance'),
        'fields' => array(
            array(
                'id' => 'favicon',
                'type' => 'media',
                'url' => false,
                'title' => esc_html__('Favicon', 'finance'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => esc_html__('Favicon.', 'finance'),
                'subtitle' => esc_html__('Favicon', 'finance'),
               'default' => array('url' => get_template_directory_uri().'/images/favicon.png'),                     
            ),
            array(
                'id' => 'logo',
                'type' => 'media',
                'url' => false,
                'title' => esc_html__('Logo Static', 'finance'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => esc_html__('logo.', 'finance'),
                'subtitle' => esc_html__('Logo', 'finance'),
               'default' => array('url' => get_template_directory_uri().'/images/logo.png'),                     
            ),  
            array(
                'id' => 'logo2',
                'type' => 'media',
                'url' => false,
                'title' => esc_html__('Logo Light', 'finance'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => esc_html__('logo light, use for header layout 2, 6.', 'finance'),
               'default' => array('url' => get_template_directory_uri().'/images/logo-light.png'),                     
            ),                                             
        )
    ) );    
    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-qrcode',
        'title' => esc_html__('Header Settings', 'finance'),
        'fields' => array(
            array(
                'id'       => 'header_layout',
                'type'     => 'image_select',
                'title'    => esc_html__( 'Images Option for Header Layout', 'finance' ),
                'subtitle' => esc_html__( 'Use any header layout for all pages.', 'finance' ),
                'options'  => array(
                    'header1' => array(
                        'alt' => 'Header Layout 1',
                        'img' => get_template_directory_uri().'/images/theme-options/header1.jpg'
                    ),
                    'header2' => array(
                        'alt' => 'Header Layout 2',
                        'img' => get_template_directory_uri().'/images/theme-options/header2.jpg'
                    ),
                    'header3' => array(
                        'alt' => 'Header Layout 3',
                        'img' => get_template_directory_uri().'/images/theme-options/header3.jpg'
                    ),
                    'header4' => array(
                        'alt' => 'Header Layout 4',
                        'img' => get_template_directory_uri().'/images/theme-options/header4.jpg'
                    ),
                    'header5' => array(
                        'alt' => 'Header Layout 5',
                        'img' => get_template_directory_uri().'/images/theme-options/header5.jpg'
                    ),
                    'header6' => array(
                        'alt' => 'Header Layout 6',
                        'img' => get_template_directory_uri().'/images/theme-options/header6.jpg',
                    )
                ),
                'default'  => 'header5'
            ),
            array(
                'id' => 'address_header',
                'type' => 'text',
                'title' => esc_html__('Address', 'finance'),
                'desc' => esc_html__('Address in header', 'finance'),
                'default' => '8th floor, 379 Hudson St,'
            ),
            array(
                'id' => 'country_header',
                'type' => 'text',
                'title' => esc_html__('Country', 'finance'),
                'desc' => esc_html__('Country in header', 'finance'),
                'default' => 'New York, NY 10018'
            ),
            array(
                'id' => 'phone_header',
                'type' => 'text',
                'title' => esc_html__('Phone Number', 'finance'),
                'desc' => esc_html__('Phone in header', 'finance'),
                'default' => '1-800-123-6879'
            ),
            array(
                'id' => 'email_header',
                'type' => 'text',
                'title' => esc_html__('Email', 'finance'),
                'desc' => esc_html__('Email in header', 'finance'),
                'default' => 'contact@finance.com'
            ),
            array(
                'id' => 'hb_text',
                'type' => 'text',
                'title' => esc_html__('Button Text', 'finance'),
                'desc' => esc_html__('Button text in header', 'finance'),
                'default' => 'Get A Quote'
            ),
            array(
                'id' => 'hb_link',
                'type' => 'text',
                'title' => esc_html__('Button Link', 'finance'),
                'desc' => esc_html__('Link of button in header', 'finance'),
                'default' => ''
            ),                                          
        )
    ) );
    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Date Time Header layout 2 + 3 + 4.', 'finance' ),
        'id'         => 'design-header2',
        'subsection' => true,
        'fields'     => array(
            array(
                'id' => 'time_header',
                'type' => 'text',
                'title' => esc_html__('Time', 'finance'),
                'desc' => esc_html__('Time in header.', 'finance'),
                'default' => ''
            ),
            array(
                'id' => 'date_header',
                'type' => 'text',
                'title' => esc_html__('Date', 'finance'),
                'desc' => esc_html__('Date in header.', 'finance'),
                'default' => ' Monday to Friday'
            ),    
        ),        
    ) );
    Redux::setSection( $opt_name, array(
        'title'      => esc_html__( 'Top Header layout 3 + 4.', 'finance' ),
        'id'         => 'design-header3',
        'subsection' => true,
        'fields'     => array(
            array(
                'id' => 'top_left_ht',
                'type' => 'text',
                'title' => esc_html__('Text in top left header', 'finance'),
                'desc' => esc_html__('Add text for top left  header.', 'finance'),
                'default' => 'We are help you with all your financial'
            ),
            array(
                'id' => 'top_language',
                'type' => 'editor',
                'title' => esc_html__('Add language html code, shortcode, etc...', 'finance'),
                'subtitle' => esc_html__('Add language', 'finance'),
                'default' => '',
            ),
        ),        
    ) );   
    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-font',
        'title' => esc_html__('Typography', 'finance'),
        'fields' => array(
            array(
                'id' => 'h1-typography',
                'type' => 'typography',
                'output' => array('h1'),
                'title' => esc_html__('Heading 1', 'finance'),
                'subtitle' => esc_html__('Specify the heading 1 font properties.', 'finance'),
                'google' => true,
                'default' => array(
                    'color'       => '', 
                    'font-style'  => '', 
                    'font-family' => '',
                    'font-size'   => '', 
                    'line-height' => ''
                ),
            ),   
            array(
                'id' => 'h2-typography',
                'type' => 'typography',
                'output' => array('h2'),
                'title' => esc_html__('Heading 2', 'finance'),
                'subtitle' => esc_html__('Specify the heading 2 font properties.', 'finance'),
                'google' => true,
                'default' => array(
                    'color'       => '', 
                    'font-style'  => '', 
                    'font-family' => '',
                    'font-size'   => '', 
                    'line-height' => ''
                ),
            ), 
            array(
                'id' => 'h3-typography',
                'type' => 'typography',
                'output' => array('h3'),
                'title' => esc_html__('Heading 3', 'finance'),
                'subtitle' => esc_html__('Specify the heading 3 font properties.', 'finance'),
                'google' => true,
                'default' => array(
                    'color'       => '', 
                    'font-style'  => '', 
                    'font-family' => '',
                    'font-size'   => '', 
                    'line-height' => ''
                ),
            ), 
            array(
                'id' => 'h4-typography',
                'type' => 'typography',
                'output' => array('h4'),
                'title' => esc_html__('Heading 4', 'finance'),
                'subtitle' => esc_html__('Specify the heading 4 font properties.', 'finance'),
                'google' => true,
                'default' => array(
                    'color'       => '', 
                    'font-style'  => '', 
                    'font-family' => '',
                    'font-size'   => '', 
                    'line-height' => ''
                ),
            ), 
            array(
                'id' => 'h5-typography',
                'type' => 'typography',
                'output' => array('h5'),
                'title' => esc_html__('Heading 5', 'finance'),
                'subtitle' => esc_html__('Specify the heading 5 font properties.', 'finance'),
                'google' => true,
                'default' => array(
                    'color'       => '', 
                    'font-style'  => '', 
                    'font-family' => '',
                    'font-size'   => '', 
                    'line-height' => ''
                ),
            ), 
            array(
                'id' => 'h6-typography',
                'type' => 'typography',
                'output' => array('h6'),
                'title' => esc_html__('Heading 6', 'finance'),
                'subtitle' => esc_html__('Specify the heading 6 font properties.', 'finance'),
                'google' => true,
                'default' => array(
                    'color'       => '', 
                    'font-style'  => '', 
                    'font-family' => '',
                    'font-size'   => '', 
                    'line-height' => ''
                ),
            ),                                 
        )
    ) );

    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-blogger',
        'title' => esc_html__('Blog Settings', 'finance'),
        'fields' => array(
            array(
                'id' => 'blog_excerpt',
                'type' => 'text',
                'title' => esc_html__('Blog custom excerpt lenght', 'finance'),
                'subtitle' => esc_html__('Input Blog custom excerpt lenght', 'finance'),
                'desc' => esc_html__('Blog custom excerpt lenght', 'finance'),
                'default' => '30'
            ),
            array(
                'id' => 'the_blog_single',
                'type' => 'text',
                'title' => esc_html__('The Blog Single Title', 'finance'),
                'subtitle' => esc_html__('Input blog single', 'finance'),
                'desc' => esc_html__('The Blog Single Title', 'finance'),
                'default' => 'The Blog Single'
            ),                
         )
    ) );     
    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-graph',
        'title' => esc_html__('404 Settings', 'finance'),
        'fields' => array(
            array(
                'id' => '404_img',
                'type' => 'media',
                'title' => esc_html__('404 Image', 'finance'),
                'subtitle' => esc_html__('Upload your 404 image', 'finance'),
                'desc' => esc_html__('Upload your 404 image', 'finance'),                        
                'default' => array('url' => get_template_directory_uri().'/images/404.png'),
            ), 
            array(
                'id' => '404_title',
                'type' => 'text',
                'title' => esc_html__('404 Title', 'finance'),
                'subtitle' => esc_html__('Input 404 Title', 'finance'),
                'desc' => esc_html__('404 Title', 'finance'),
                'default' => '404'
            ),                              
            array(
                'id' => '404_content',
                'type' => 'editor',
                'title' => esc_html__('404 Content', 'finance'),
                'subtitle' => esc_html__('Enter 404 Content', 'finance'),
                'desc' => esc_html__('404 Content', 'finance'),
                'default' => 'Oop! We are sorry, the page not found!'
            ),      
            array(
                'id' => 'back_404',
                'type' => 'text',
                'title' => esc_html__('Button Back Home', 'finance'),                        
                'desc' => esc_html__('Text Button Go To Home.', 'finance'),
                'subtitle' => esc_html__('Button Back Home', 'finance'),
                'default' => 'Back To Home',
            ),                  
         )
    ) );
    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-group',
        'title' => esc_html__('Social Settings', 'finance'),
        'fields' => array(
            array(
                'id' => 'facebook',
                'type' => 'text',
                'title' => esc_html__('Facebook Url', 'finance'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => 'https://www.facebook.com/',
            ),
            array(
                'id' => 'twitter',
                'type' => 'text',
                'title' => esc_html__('Twitter Url', 'finance'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => 'https://twitter.com/',
            ),
            array(
                'id' => 'google',
                'type' => 'text',
                'title' => esc_html__('Google+ Url', 'finance'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => 'https://plus.google.com',
            ),                      
            array(
                'id' => 'github',
                'type' => 'text',
                'title' => esc_html__('Github Url', 'finance'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ),
            array(
                'id' => 'youtube',
                'type' => 'text',
                'title' => esc_html__('Youtube Url', 'finance'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '',
            ),
            array(
                'id' => 'linkedin',
                'type' => 'text',
                'title' => esc_html__('Linkedin Url', 'finance'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '',
            ),
            array(
                'id' => 'dribbble',
                'type' => 'text',
                'title' => esc_html__('Dribbble Url', 'finance'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '',
            ),
            array(
                'id' => 'behance',
                'type' => 'text',
                'title' => esc_html__('Behance Url', 'finance'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ),
            array(
                'id' => 'instagram',
                'type' => 'text',
                'title' => esc_html__('Instagram Url', 'finance'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ),
            array(
                'id' => 'skype',
                'type' => 'text',
                'title' => esc_html__('Skype Url', 'finance'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ),  
            array(
                'id' => 'pinterest',
                'type' => 'text',
                'title' => esc_html__('pinterest Url', 'finance'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ), 
            array(
                'id' => 'flickr',
                'type' => 'text',
                'title' => esc_html__('flickr Url', 'finance'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ), 
            array(
                'id' => 'vimeo',
                'type' => 'text',
                'title' => esc_html__('vimeo Url', 'finance'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ), 
            array(
                'id' => 'tumblr',
                'type' => 'text',
                'title' => esc_html__('tumblr Url', 'finance'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ), 
            array(
                'id' => 'soundcloud',
                'type' => 'text',
                'title' => esc_html__('soundcloud Url', 'finance'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ), 
            array(
                'id' => 'lastfm',
                'type' => 'text',
                'title' => esc_html__('lastfm Url', 'finance'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => ''
            ), 
            array(
                'id' => 'rss',
                'type' => 'text',
                'title' => esc_html__('RSS Url', 'finance'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '',
            ),  
            array(
                'id' => 'email',
                'type' => 'text',
                'title' => esc_html__('Email Address', 'finance'),
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'default' => '',
            ), 
            array(
                'id' => 'social_extend',
                'type' => 'editor',
                'title' => esc_html__('Add your social extend', 'finance'),
                'subtitle' => esc_html__('Add your social html code here, if your social network not have in listed social network above.', 'finance'),
                'description' => esc_html__('HTML code: <li><a target="_blank" href="#"><i class="fa fa-facebook"></i></a></li> , find more icons: https://fontawesome.com/v4.7.0/icons/#brand', 'finance'),
                'default' => '',
            ), 
        )
    ) );Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-hourglass',
                'title' => esc_html__('Comming Soon Settings', 'finance'),
                'fields' => array( 
                    array(
                        'id' => 'date_cs',
                        'type' => 'date',
                        'title' => esc_html__('Date Comming Soon', 'finance'),
                        'default' => '12/30/2017',
                    ),       
                    array(
                        'id' => 'bg_cs',
                        'type' => 'media',
                        'title' => esc_html__('Background Image', 'finance'),
                        'subtitle' => esc_html__('Background Image', 'finance'),
                        'desc' => esc_html__('Use For Comming Soon Page', 'finance'),
                        'default' => array('url' => get_template_directory_uri().'/images/commingsoon.jpg')
                    ), 
                    array(
                        'id' => 'title_cs',
                        'type' => 'text',
                        'title' => esc_html__('Title Comming Soon', 'finance'),
                        'default' => 'Comming Soon',
                    ),
                    array(
                        'id' => 'stitle_cs',
                        'type' => 'text',
                        'title' => esc_html__('Subtitle Comming Soon', 'finance'),
                        'default' => 'Our website is under construction, follow us for update now!',
                    ),                                                    
                )    
    ));
    Redux::setSection( $opt_name, array(
        'icon' => ' el-icon-credit-card',
        'title' => esc_html__('Footer Settings', 'finance'),
        'fields' => array(   
            array(
                'id'       => 'footer-select-pages',
                'type'     => 'select',
                'data'     => 'pages',
                'title'    => esc_html__( 'Pages Select Option', 'finance' ),
                'subtitle' => esc_html__( 'No validation can be done on this field type', 'finance' ),
                'desc'     => esc_html__( 'This is the description field, again good for additional info.', 'finance' ),
            ),                 
            array(
                'id' => 'footer_text',
                'type' => 'editor',
                'title' => esc_html__('Footer Text', 'finance'),
                'subtitle' => esc_html__('Copyright Text', 'finance'),
                'default' => 'Copyright 2016 - finance by ThemeModern',
            ),                    
        )
    ) );
    
    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-website',
        'title' => esc_html__('Styling Options', 'finance'),
        'fields' => array(                
            array(
                'id' => 'main-color',
                'type' => 'color',
                'title' => esc_html__('Theme Main Color', 'finance'),
                'subtitle' => esc_html__('Pick the main color for the theme (default: #00abc9).', 'finance'),
                'default' => '#00abc9',
                'validate' => 'color',
            ),  
            array(
                'id' => 'main-color-hover',
                'type' => 'color',
                'title' => esc_html__('Hover Color', 'finance'),
                'subtitle' => esc_html__('Pick the hover color for the theme (default: #008096).', 'finance'),
                'default' => '#008096',
                'validate' => 'color',
            ),
            array(
                'id' => 'body-font2',
                'type' => 'typography',
                'output' => array('body'),
                'title' => esc_html__('Body Font', 'finance'),
                'subtitle' => esc_html__('Specify the body font properties.', 'finance'),
                'google' => true,
                'default' => array(
                    'color' => '',
                    'font-size' => '',
                    'line-height' => '',
                    'font-family' => '',
                    'font-weight' => ''
                ),
            ),
             array(
                'id' => 'custom-css',
                'type' => 'ace_editor',
                'title' => esc_html__('CSS Code', 'finance'),
                'subtitle' => esc_html__('Paste your CSS code here.', 'finance'),
                'mode' => 'css',
                'theme' => 'monokai',
                'desc' => 'Possible modes can be found at http://ace.c9.io/.',
                'default' => "#header{\nmargin: 0 auto;\n}"
            ),
        )
    ) );

    /*
     * <--- END SECTIONS
     */
