<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package finance
 */

if ( ! function_exists( 'finance_entry_meta' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function finance_entry_meta() {
    // Hide category and tag text for pages.
    if ( 'post' === get_post_type() ) {
        /* translators: used between list items, there is a space after the comma */
        $categories_list = get_the_category_list( esc_html__( ', ', 'finance' ) );
        if ( $categories_list && finance_theme_categorized_blog() ) {
            printf( '<span class="tags">' . esc_html__( ' %1$s', 'finance' ) . '</span>', $categories_list ); // WPCS: XSS OK.
        }
    }
    $time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
    if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
        $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
    }

    $time_string = sprintf( $time_string,
        esc_attr( get_the_date( 'c' ) ),
        esc_html( get_the_date() ),
        esc_attr( get_the_modified_date( 'c' ) ),
        esc_html( get_the_modified_date() )
    );

    $posted_on = sprintf(
        esc_html_x( '%s', 'post date', 'finance' ), $time_string );
    echo '<span class="dates"> ' . $posted_on . '</span>';
    //the_time( get_option( 'date_format' ) );
}
endif;
                      

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function finance_theme_categorized_blog() {
    if ( false === ( $all_the_cool_cats = get_transient( 'finance_theme_categories' ) ) ) {
        // Create an array of all the categories that are attached to posts.
        $all_the_cool_cats = get_categories( array(
            'fields'     => 'ids',
            'hide_empty' => 1,

            // We only need to know if there is more than one category.
            'number'     => 2,
        ) );

        // Count the number of categories that are attached to the posts.
        $all_the_cool_cats = count( $all_the_cool_cats );

        set_transient( 'finance_theme_categories', $all_the_cool_cats );
    }

    if ( $all_the_cool_cats > 1 ) {
        // This blog has more than 1 category so finance_theme_categorized_blog should return true.
        return true;
    } else {
        // This blog has only 1 category so finance_theme_categorized_blog should return false.
        return false;
    }
}

/**
 * Flush out the transients used in finance_theme_categorized_blog.
 */
function finance_theme_category_transient_flusher() {
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
        return;
    }
    // Like, beat it. Dig?
    delete_transient( 'finance_theme_categories' );
}
add_action( 'edit_category', 'finance_theme_category_transient_flusher' );
add_action( 'save_post',     'finance_theme_category_transient_flusher' );

if ( ! function_exists( 'finance_excerpt_length' ) ) :
/**** Change length of the excerpt ****/
function finance_excerpt_length() {
      global $finance_option;
      if(isset($finance_option['blog_excerpt'])){
        $limit = $finance_option['blog_excerpt'];
      }else{
        $limit = 15;
      }  
      $excerpt = explode(' ', get_the_excerpt(), $limit);

      if (count($excerpt)>=$limit) {
        array_pop($excerpt);
        $excerpt = implode(" ",$excerpt).'...';
      } else {
        $excerpt = implode(" ",$excerpt);
      } 
      $excerpt = preg_replace('`[[^]]*]`','',$excerpt);
      return $excerpt;
}
endif;

if ( ! function_exists( 'finance_excerpt' ) ) :
/** Excerpt Section Blog Post **/
function finance_excerpt($limit) {
  $excerpt = explode(' ', get_the_excerpt(), $limit);
  if (count($excerpt)>=$limit) {
    array_pop($excerpt);
    $excerpt = implode(" ",$excerpt).'...';
  } else {
    $excerpt = implode(" ",$excerpt);
  }
  $excerpt = preg_replace('`[[^]]*]`','',$excerpt);
  return $excerpt;
}
endif;

if ( ! function_exists( 'finance_tag_cloud_widget' ) ) :
/**custom function tag widgets**/
function finance_tag_cloud_widget($args) {
    $args['number'] = 0; //adding a 0 will display all tags
    $args['largest'] = 18; //largest tag
    $args['smallest'] = 14; //smallest tag
    $args['unit'] = 'px'; //tag font unit
    $args['format'] = 'list'; //ul with a class of wp-tag-cloud
    $args['exclude'] = ''; //exclude tags by ID
    return $args;
}
add_filter( 'widget_tag_cloud_args', 'finance_tag_cloud_widget' );
endif;

if ( ! function_exists( 'finance_pagination' ) ) :
//pagination
function finance_pagination($prev = '<i class="fa fa-angle-left"></i>', $next = '<i class="fa fa-angle-right"></i>', $pages='') {
    global $wp_query, $wp_rewrite;
    $wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;
    if($pages==''){
        global $wp_query;
         $pages = $wp_query->max_num_pages;
         if(!$pages)
         {
             $pages = 1;
         }
    }
    $pagination = array(
        'base'          => str_replace( 999999999, '%#%', get_pagenum_link( 999999999 ) ),
        'format'        => '',
        'current'       => max( 1, get_query_var('paged') ),
        'total'         => $pages,
        'prev_text' => $prev,
        'next_text' => $next,       
        'type'          => 'list',
        'end_size'      => 3,
        'mid_size'      => 3
);
    $return =  paginate_links( $pagination );
    echo str_replace( "<ul class='page-numbers'>", '<ul class="pagination pagination-finance">', $return );
}
endif;

if ( ! function_exists( 'finance_custom_wp_admin_style' ) ) :
function finance_custom_wp_admin_style() {

        wp_register_style( 'finance_custom_wp_admin_css', get_template_directory_uri() . '/framework/admin/admin-style.css', false, '1.0.0' );
        wp_enqueue_style( 'finance_custom_wp_admin_css' );

        wp_enqueue_script( 'finance-backend-js', get_template_directory_uri()."/framework/admin/admin-script.js", array( 'jquery' ), '1.0.0', true );
        wp_enqueue_script( 'finance-backend-js' );
}
add_action( 'admin_enqueue_scripts', 'finance_custom_wp_admin_style' );
endif;

if ( ! function_exists( 'finance_search_form' ) ) :
/* Custom form search */
function finance_search_form( $form ) {
    $form = '<form class="search-form" role="search" method="get" action="' . esc_url(home_url( '/' )) . '" >  
        <input type="search" id="search" class="search-field" value="' . get_search_query() . '" name="s" placeholder="'.__('Search', 'finance').'" />
        <button class="search-submit" type="submit"><i class="fa fa-search"></i></button>
    </form>';
    return $form;
}
add_filter( 'get_search_form', 'finance_search_form' );
endif;

/* Custom comment List: */
function finance_theme_comment($comment, $args, $depth) {    
   $GLOBALS['comment'] = $comment; ?>
   <li class="comment">
      <div class="comment-body">
        <div class="comment-meta">
            <div class="comment-author vcard">
                <?php echo get_avatar($comment,$size='50',$default='http://0.gravatar.com/avatar/ad516503a11cd5ca435acc9bb6523536?s=100' ); ?>
            </div>
        </div>
        <div class="comment-content">
            <?php if ($comment->comment_approved == '0'){ ?>
                 <p><em><?php esc_html_e('Your comment is awaiting moderation.','finance') ?></em></p>
            <?php }else{ ?>
                <?php comment_text() ?>
             <?php } ?>
             <cite class="fn"><a><?php printf(__('%s','finance'), get_comment_author()) ?></a></cite>
            <a class="comment-date"><span><?php the_time( get_option( 'date_format' ) ); ?></span></a>
            <div class="reply"><?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?></div>
        </div>   
      </div>
    </li> 
<?php
}

if ( ! function_exists( 'finance_custom_header_socials' ) ) :
/**
 * Prints HTML with Custom Favicon.
 */
function finance_custom_header_socials() {
    global $finance_option;
    
    echo '<ul class="social">';
      if($finance_option['facebook']!=''){ 
          echo '<li class="facebook"><a class="social-icon" target="_blank" href="' . esc_url($finance_option['facebook']) . '"><i class="fa fa-facebook"></i></a></li>';
      } 
      if($finance_option['twitter']!=''){ 
          echo '<li class="twitter"><a class="social-icon" target="_blank" href="' . esc_url($finance_option['twitter']) . '"><i class="fa fa-twitter"></i></a></li>';
      } 
      if($finance_option['google']!=''){ 
          echo '<li class="google-plus"><a class="social-icon" target="_blank" href="' . esc_url($finance_option['google']) . '"><i class="fa fa-google-plus"></i></a></li>';
      }   
      if($finance_option['youtube']!=''){ 
          echo '<li class="youtube"><a class="social-icon" target="_blank" href="' . esc_url($finance_option['youtube']) . '"><i class="fa fa-youtube"></i></a></li>';
      } 
      if($finance_option['linkedin']!=''){ 
          echo '<li class="linkedin"><a class="social-icon" target="_blank" href="' . esc_url($finance_option['linkedin']) . '"><i class="fa fa-linkedin"></i></a></li>';
      }  
      if($finance_option['pinterest']!=''){ 
          echo '<li class="pinterest"><a class="social-icon" target="_blank" href="' . esc_url($finance_option['pinterest']) . '"><i class="fa fa-pinterest"></i></a></li>';
      } 
      if($finance_option['flickr']!=''){ 
          echo '<li class="flickr"><a class="social-icon" target="_blank" href="' . esc_url($finance_option['flickr']) . '"><i class="fa fa-flickr"></i></a></li>';
      } 
      if($finance_option['instagram']!=''){ 
           echo '<li class="instagram"><a class="social-icon" target="_blank" href="' . esc_url($finance_option['instagram']) . '"><i class="fa fa-instagram"></i></a></li>';            
      } 
      if($finance_option['github']!=''){ 
          echo '<li class="github"><a class="social-icon" target="_blank" href="' . esc_url($finance_option['github']) . '"><i class="fa fa-github"></i></a></li>';
      } 
      if($finance_option['dribbble']!=''){ 
          echo '<li class="dribbble"><a class="social-icon" target="_blank" href="' . esc_url($finance_option['dribbble']) . '"><i class="fa fa-dribbble"></i></a></li>';
      } 
      if($finance_option['behance']!=''){ 
          echo '<li class="behance"><a class="social-icon" target="_blank" href="' . esc_url($finance_option['behance']) . '"><i class="fa fa-behance"></i></a></li>';
      }   
      if($finance_option['skype']!=''){ 
           echo '<li class="skype"><a class="social-icon" href="' . esc_attr($finance_option['skype']) . '"><i class="fa fa-skype"></i></a></li>';
      } 
      if($finance_option['vimeo']!=''){ 
          echo '<li class="vimeo"><a class="social-icon" target="_blank" href="' . esc_url($finance_option['vimeo']) . '"><i class="fa fa-vimeo"></i></a></li>';
      }   
      if($finance_option['tumblr']!=''){ 
          echo '<li class="tumblr"><a class="social-icon" target="_blank" href="' . esc_url($finance_option['tumblr']) . '"><i class="fa fa-tumblr"></i></a></li>';
      } 
      if($finance_option['soundcloud']!=''){ 
          echo '<li class="soundcloud"><a class="social-icon" target="_blank" href="' . esc_url($finance_option['soundcloud']) . '"><i class="fa fa-soundcloud"></i></a></li>';
      } 
      if($finance_option['lastfm']!=''){ 
          echo '<li class="lastfm"><a class="social-icon" target="_blank" href="' . esc_url($finance_option['lastfm']) . '"><i class="fa fa-lastfm"></i></a></li>';            
      } 
      if($finance_option['rss']!=''){ 
        echo '<li class="rss"><a class="social-icon" target="_blank" href="' . esc_url($finance_option['rss']) . '"><i class="fa fa-rss"></i></a></li>';            
      } 
      if($finance_option['email']!=''){ 
        echo '<li class="email"><a class="social-icon" href="mailto:' . esc_attr($finance_option['email']) . '"><i class="fa fa-envelope"></i></a></li>';            
      } 
      if( !empty( $finance_option['social_extend'] ) ){ 
        echo $finance_option['social_extend'];
      }
    echo '</ul>';
}
endif;

// Add specific CSS class by filter
add_filter( 'body_class', 'finance_body_class_names' );
function finance_body_class_names( $classes ) {
  global $finance_option;

  // add 'class-name' to the $classes array
  if(is_page_template('page-templates/template-canvas.php') ){
    $classes[] = 'header-fixed '; 
  }else{
    $classes[] = 'header-normal ';
  }

  // return the $classes array
  return $classes;
}

if ( ! function_exists( 'finance_custom_favicon' ) ) :
/**
 * Prints HTML with Custom Favicon.
 */
function finance_custom_favicon() {
    global $finance_option;
    
    if ( ! function_exists( 'has_site_icon' ) || ! has_site_icon() ) {        
        if($finance_option['favicon']['url'] !=''){ 
            echo '<link rel="shortcut icon" href="'.($finance_option['favicon']['url']).'">';    
        }
    } 
}
endif;