<?php
/**
 * Redux Theme functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package finance
 */

if ( ! class_exists( 'ReduxFramewrk' ) ) {
    require_once( get_template_directory() . '/framework/sample-config.php' );
	function finance_removeDemoModeLink() { // Be sure to rename this function to something more unique
		if ( class_exists('ReduxFrameworkPlugin') ) {
			remove_filter( 'plugin_row_meta', array( ReduxFrameworkPlugin::get_instance(), 'plugin_metalinks'), null, 2 );
		}
		if ( class_exists('ReduxFrameworkPlugin') ) {
			remove_action('admin_notices', array( ReduxFrameworkPlugin::get_instance(), 'admin_notices' ) );    
		}
	}
	add_action('init', 'finance_removeDemoModeLink');
}

if ( ! function_exists( 'finance_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function finance_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Redux Theme, use a find and replace
	 * to change 'finance' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'finance', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'custom-header' );
	add_theme_support( 'custom-background' ); 

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'finance' ),
		'footermenu' => esc_html__( 'Footer Menu', 'finance' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'audio',
		'image',
		'video',
		'quote',
		'gallery',
	) );
}
endif; // finance_setup
add_action( 'after_setup_theme', 'finance_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function finance_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'finance_content_width', 640 );
}
add_action( 'after_setup_theme', 'finance_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function finance_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'finance' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Appears in the sidebar section of the site.', 'finance' ),  
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
  	register_sidebar( array(
	    'name'          => esc_html__( 'Shop Sidebar', 'finance' ),
	    'id'            => 'shop-sidebar',        
	    'description'   => esc_html__( 'Appears in the sidebar section of the site.', 'finance' ),        
	    'before_widget' => '<aside id="%1$s" class="widget %2$s">',        
	    'after_widget'  => '</aside>',        
	    'before_title'  => '<h3 class="widget-title">',        
	    'after_title'   => '</h3>'
    ) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer One Widget Area', 'finance' ),
		'id'            => 'footer-area-1',
		'description'   => esc_html__( 'Footer Widget that appears on the Footer.', 'finance' ),
		'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="text-white">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Two Widget Area', 'finance' ),
		'id'            => 'footer-area-2',
		'description'   => esc_html__( 'Footer Widget that appears on the Footer.', 'finance' ),
		'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="text-white">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Three Widget Area', 'finance' ),
		'id'            => 'footer-area-3',
		'description'   => esc_html__( 'Footer Widget that appears on the Footer.', 'finance' ),
		'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="text-white">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Fourth Widget Area', 'finance' ),
		'id'            => 'footer-area-4',
		'description'   => esc_html__( 'Footer Widget that appears on the Footer.', 'finance' ),
		'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="text-white">',
		'after_title'   => '</h3>',
	) ); 
}
add_action( 'widgets_init', 'finance_widgets_init' );

/**
 * Enqueue Google fonts.
 */
function finance_fonts_url() {
    $fonts_url = '';

    /* Translators: If there are characters in your language that are not
    * supported by Lora, translate this to 'off'. Do not translate
    * into your own language.
    */
    $open_sans = _x( 'on', 'Open Sans font: on or off', 'finance' );
 
    /* Translators: If there are characters in your language that are not
    * supported by Lora, translate this to 'off'. Do not translate
    * into your own language.
    */
    $lato = _x( 'on', 'Lato font: on or off', 'finance' );
 
    /* Translators: If there are characters in your language that are not
    * supported by Open Sans, translate this to 'off'. Do not translate
    * into your own language.
    */
    $droid_Serif = _x( 'on', 'Droid Serif font: on or off', 'finance' );

    /* Translators: If there are characters in your language that are not
    * supported by Open Sans, translate this to 'off'. Do not translate
    * into your own language.
    */
    $lora = _x( 'on', 'Lora font: on or off', 'finance' );

    /* Translators: If there are characters in your language that are not
    * supported by Open Sans, translate this to 'off'. Do not translate
    * into your own language.
    */
    $pt_Sans = _x( 'on', 'PT Sans font: on or off', 'finance' );    
 
    if ( 'off' !== $lato || 'off' !== $droid_Serif || 'off' !== $lora || 'off' !== $pt_Sans || 'off' !== $open_sans ) {
        $font_families = array();

        if ( 'off' !== $open_sans ) {
            $font_families[] = 'Open+Sans:400,400italic,600,600italic,300,300italic,700,700italic';
        }        
 
        if ( 'off' !== $lato ) {
            $font_families[] = 'Lato:400,100,100italic,300,300italic,400italic,700,700italic,900,900italic';
        }        
 
        if ( 'off' !== $droid_Serif ) {
            $font_families[] = 'Droid+Serif:700';
        }

        if ( 'off' !== $lora ) {
            $font_families[] = 'Lora';
        }  

        if ( 'off' !== $pt_Sans ) {
            $font_families[] = 'PT+Sans';
        }   
 
        $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
            'subset' => urlencode( 'latin,latin-ext' ),
        );
 
        $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
    }
 
    return esc_url_raw( $fonts_url );
}


/**
 * Enqueue scripts and styles.
 */
function finance_scripts() {
	global $finance_option;
	$gmap_api = !empty($finance_option['gmap_api']) ? esc_attr($finance_option['gmap_api']) : '';
	$protocol = is_ssl() ? 'https' : 'http';	

	// Add custom fonts, used in the main stylesheet.
    wp_enqueue_style( 'finance-fonts', finance_fonts_url(), array(), null );

    /** All frontend css files **/ 
    wp_enqueue_style( 'finance-bootstrap', get_template_directory_uri().'/css/bootstrap.min.css');
	wp_enqueue_style( 'vc_font_awesome_5');
    wp_enqueue_style( 'finance-font-awesome', get_template_directory_uri().'/css/font-awesome/css/font-awesome.min.css');
	wp_enqueue_style( 'finance-web-font', get_template_directory_uri().'/linearicons/font/style.css');    
	wp_enqueue_style( 'finance-magnific-popup', get_template_directory_uri().'/css/magnific-popup.css');
	wp_enqueue_style( 'finance-fancySelect', get_template_directory_uri().'/css/fancySelect.css');
    wp_enqueue_style( 'finance-animate', get_template_directory_uri().'/css/animate.css'); 
	wp_enqueue_style( 'finance-switcher-demo', get_template_directory_uri().'/css/owl.carousel.css');
	wp_enqueue_style( 'finance-switcher-colors', get_template_directory_uri().'/css/owl.theme.default.css');  
    wp_enqueue_style( 'finance-progressbar', get_template_directory_uri().'/css/bootstrap-progressbar-3.3.4.min.css');   
    wp_enqueue_style( 'finance-mCustomScrollbar', get_template_directory_uri().'/css/jquery.mCustomScrollbar.css'); 	
    wp_enqueue_style( 'finance-woocommerce', get_template_directory_uri().'/css/woocommerce.css');
	wp_enqueue_style( 'finance-style', get_stylesheet_uri() );

	/** All frontend javascript files **/ 
	if($finance_option['preload-switch']==true){
		wp_enqueue_script( 'finance-jpreLoader', get_template_directory_uri() . '/js/jpreLoader.js', array('jquery'), '20151228', true );
	}

	wp_enqueue_script( "finance-maps-js", "$protocol://maps.googleapis.com/maps/api/js?key=$gmap_api",array('jquery'),false,false);

	wp_enqueue_script( 'finance-waypoints', get_template_directory_uri() . '/js/jquery.waypoints.min.js', array(), '20151228', true );
	wp_enqueue_script( 'finance-bootstrap', get_template_directory_uri() . '/js/bootstrap.min.js', array(), '20151228', true );
	wp_enqueue_script( 'finance-easing', get_template_directory_uri() . '/js/easing.js', array(), '20151228', true );
	wp_enqueue_script( 'finance-mCustomScrollbar', get_template_directory_uri() . '/js/jquery.mCustomScrollbar.concat.min.js', array(), '20151228', true );
	wp_enqueue_script( 'finance-fancySelect', get_template_directory_uri() . '/js/fancySelect.js', array(), '20151228', true );	
	wp_enqueue_script( 'finance-animateNumber', get_template_directory_uri() . '/js/jquery.animateNumber.min.js', array(), '20151228', true );
	wp_enqueue_script( 'finance-mobile-menu', get_template_directory_uri() . '/js/jquery.mobile-menu.js', array(), '20151228', true );	
	wp_enqueue_script( 'finance-sticky', get_template_directory_uri() . '/js/sticky.min.js', array(), '20151228', true );
	wp_enqueue_script( 'finance-isotope.pkgd', get_template_directory_uri() . '/js/isotope.pkgd.min.js', array(), '20151228', true );
	wp_enqueue_script( 'finance-custom-isotop', get_template_directory_uri() . '/js/custom-isotope.js', array(), '20151228', true );
	wp_enqueue_script( 'finance-owl.carousel', get_template_directory_uri() . '/js/owl.carousel.js', array(), '20151228', true );
	wp_enqueue_script( 'finance-custom-owl', get_template_directory_uri() . '/js/custom-owl.js', array(), '20151228', true );
	wp_enqueue_script( 'finance-bootstrap-progressbar', get_template_directory_uri() . '/js/bootstrap-progressbar.min.js', array(), '20151228', true );
	wp_enqueue_script( 'finance-custom-progressbar', get_template_directory_uri() . '/js/custom-progressbar.js', array(), '20151228', true );
	wp_enqueue_script( 'finance-magnific-popup', get_template_directory_uri() . '/js/jquery.magnific-popup.min.js', array(), '20151228', true );
  	wp_enqueue_script( 'finance-chart-loader', get_template_directory_uri() . '/js/chart-loader.js', array(), '20151228', false );
	wp_enqueue_script( 'finance-custom', get_template_directory_uri() . '/js/custom.js', array(), '20151228', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'finance_scripts' );

if(!function_exists('finance_custom_frontend_scripts')){
    function finance_custom_frontend_scripts(){
        global $finance_option; 
    ?>
        <script type="text/javascript">
            window.jQuery = window.$ = jQuery;  
            (function($) { "use strict";
            	<?php if($finance_option['preload-switch']==true){ ?>
            		$(document).ready(function(){
				        // <!-- Initializing the loading images lazy -->
				        // $('.header-v1').css("top",-110);
				        $('#page').css("opacity",0);
				      
				        //calling jPreLoader function with properties
				        $('body').jpreLoader({
					        splashID: "#jSplash",
					        splashFunction: function() {  //passing Splash Screen script to jPreLoader
					          	$('#jSplash').hide().fadeIn(100);
					        }
				        }, function() { //jPreLoader callback function
					        // $('.header-v1').animate({"top":0}, 800, function() {
					        // });
					        $('#page').css("opacity",1);					       
				        });
				    });
            	<?php }	?>
                  
                <?php if(isset($finance_option['header_layout']) and $finance_option['header_layout']=="header6" ){ ?>
	            	//caches a jQuery object containing the header element
			        var header = $(".header-v6");
			        $(window).scroll(function() {
			            var scroll = $(window).scrollTop();
			            if (scroll >= 200) {
			                header.addClass("alpha-1");			                
			            } else {
			               header.removeClass("alpha-1");			               
			            }
			        });

			        // add class menu 2
				    $('#sticked-menu-2').find('ul > li').each(function(i, ojb) {
				        if ( $(this).hasClass('') ) {
				            $(this).addClass('has-sub');
				        }
				    });

				    $('#sticked-menu-2').find('.navi-desktop-site > ul > li > ul').each(function(i, ojb) {
				        if ( $(this).hasClass('') ) {
				            $(this).addClass('navi-level-2');
				        }
				    });

				    $('#sticked-menu-2').find('.navi-desktop-site > ul > li > ul > li > ul').each(function(i, ojb) {
				        if ( $(this).hasClass('') ) {
				            $(this).addClass('navi-level-3');
				        }
				    });
		        <?php }else{ ?>
			        // --------------------------------------------------
				    // Sticky Header
				    // --------------------------------------------------
				    var a = false,
				        b = null;
				    $(window).scroll(function() {
				        $(window).scrollTop() > 200 ? a || (b = new Waypoint.Sticky({
				            element: $("#sticked-menu")
				        }), a = true, $("#sticked-menu").addClass("animated slideInDown")) : (b && (b.destroy(), a = false), $("#sticked-menu").removeClass("animated slideInDown"))
				    });
				<?php } ?>    

            })(jQuery);
        </script>
    <?php        
    }
}
add_action('wp_footer', 'finance_custom_frontend_scripts');

/**
 * Implement the Custom Meta Boxs.
 */
require get_template_directory() . '/framework/meta-boxes.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/framework/template-tags.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/framework/customizer.php';

/**
 * Custom woocommerce for this theme.
 */
require get_template_directory() . '/framework/woocommerce-customize.php';
/**
 * Customizer Menu.
 */
require get_template_directory() . '/framework/wp_bootstrap_navwalker.php';

//Code Visual Composer.
// Add new Param in Row
if(function_exists('vc_add_param')){
	vc_add_param(
		'vc_row',
		array(
			"type" => "dropdown",
			"heading" => esc_html__('Setup Full width For Row.', 'finance'),
			"param_name" => "fullwidth",
			"value" => array(   
			                esc_html__('No', 'finance') => 'no',  
			                esc_html__('Yes', 'finance') => 'yes',                                                                                
			              ),
			"description" => esc_html__("Select Full width for row : yes or not, Default: No fullwidth", "finance"),      
        )
    );
    
		  
}

if(function_exists('vc_remove_param')){
	vc_remove_param( "vc_row", "full_width" );
    vc_remove_param( "vc_row", "content_placement" );  
    vc_remove_param( "vc_row", "gap" );  
    vc_remove_param( "vc_row", "full_height" );  
    vc_remove_param( "vc_row", "columns_placement" );  
    vc_remove_param( "vc_row", "video_bg" );  
    vc_remove_param( "vc_row", "video_bg_url" );  
    vc_remove_param( "vc_row", "video_bg_parallax" );  
    vc_remove_param( "vc_row", "parallax" );   
    vc_remove_param( "vc_row", "parallax_image" );  
    vc_remove_param( "vc_row", "parallax_speed_video" );  
    vc_remove_param( "vc_row", "parallax_speed_bg" );
}	

/**
 * Require plugins install for this theme.
 *
 * @since Split Vcard 1.0
 */
require_once get_template_directory() . '/framework/plugin-requires.php';



